aboutsummaryrefslogtreecommitdiff
path: root/internal/stupidgcm/gcm.go
diff options
context:
space:
mode:
Diffstat (limited to 'internal/stupidgcm/gcm.go')
-rw-r--r--internal/stupidgcm/gcm.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/internal/stupidgcm/gcm.go b/internal/stupidgcm/gcm.go
index a9377b1..c38dd5f 100644
--- a/internal/stupidgcm/gcm.go
+++ b/internal/stupidgcm/gcm.go
@@ -23,10 +23,10 @@ type stupidGCM struct {
stupidAEADCommon
}
// New returns a new AES-GCM-256 cipher that satisfies the cipher.AEAD interface.
//
// Only 32-bytes keys and 16-byte IVs are supported.
-func New(keyIn []byte, forceDecode bool) cipher.AEAD {
+func NewAES256GCM(keyIn []byte, forceDecode bool) cipher.AEAD {
if len(keyIn) != keyLen {
log.Panicf("Only %d-byte keys are supported", keyLen)
}
@@ -23,10 +23,10 @@ type stupidGCM struct {
stupidAEADCommon
}
-// New returns a new AES-GCM-256 cipher that satisfies the cipher.AEAD interface.
+// NewAES256GCM returns a new AES-256-GCM cipher that satisfies the cipher.AEAD interface.
//
// Only 32-bytes keys and 16-byte IVs are supported.